@@ -63,6 +63,30 @@ def test_get_compilation_tool():
             == 'invalid')
 
 
+@pytest.mark.language('c')
+def test_locate_library_file():
+    r"""Test locate_file method for compiler."""
+    from yggdrasil.drivers.CModelDriver import CModelDriver
+    compiler = CModelDriver.get_tool('compiler').__class__
+    files = {}
+    for k in ['shared', 'static']:
+        fname = CModelDriver.external_libraries['zmq'].get(k, '')
+        if os.path.isfile(fname):
+            files[k] = fname
+    if not files:
+        pytest.skip("Test library (zmq) doesn't exist")
+    for libtype, fname in files.items():
+        assert compiler.locate_file(fname) == fname
+        assert compiler.locate_file('zmq', libtype=libtype) == fname
+        if libtype == 'static':
+            assert compiler.archiver().locate_file('zmq') == fname
+        if libtype == 'shared':
+            assert compiler.linker().locate_file('zmq') == fname
+    if platform._is_win and 'shared' in files:
+        assert (compiler.locate_file('zmq', libtype='windows_import')
+                == files['shared'])
+
+
 def test_CompilationToolBase():
     r"""Test error in CompilationToolBase."""
     with pytest.raises(RuntimeError):
@@ -352,6 +376,7 @@ class TestCompiledModelDriver(model_base_class):
             with pytest.raises(RuntimeError):
                 python_class.executable_command(['test'], exec_type='linker')
         else:
+            python_class.executable_command(['test'], dont_link=True)
             python_class.executable_command(['test'], exec_type='linker')
 
     def test_compiler_call(self, python_class):
