@@ -11,31 +11,31 @@ case $1 in
     "" | -p | --python )
 	echo "Running Python"
 	yaml1='server_python.yml'
-	yaml2='client_python.yml'
+	yaml2='client_c.yml'
 	;;
     -m | --matlab )
 	echo "Running Matlab"
 	yaml1='server_python.yml'
-	yaml2='client_matlab.yml'
+	yaml2='client_c.yml'
 	;;
     -c | --gcc )
 	echo "Running C"
-	yaml1='server_python.yml'
+	yaml1='server_c.yml'
 	yaml2='client_c.yml'
 	;;
     --cpp | --g++)
 	echo "Running C++"
-	yaml1='server_python.yml'
+	yaml1='server_cpp.yml'
 	yaml2='client_cpp.yml'
 	;;
     -R | -r | --R | --r )
 	echo "Running R"
-	yaml1='server_python.yml'
-	yaml2='client_r.yml'
+	yaml1='server_r.yml'
+	yaml2='client_c.yml'
 	;;
     -f | --fortran )
 	echo "Running Fortran"
-	yaml1='server_python.yml'
+	yaml1='server_fortran.yml'
 	yaml2='client_fortran.yml'
 	;;
 esac
