@@ -156,6 +156,10 @@ public:
     @returns YggGeneric* Pointer to C object.
    */
   YggGeneric* python2c(PyObject *pyobj) const override {
+    YggGeneric *cobj = NULL;
+#ifdef YGGDRASIL_DISABLE_PYTHON_C_API
+    ygglog_throw_error("ObjMetaschemaType::python2c: Python disabled");
+#else // YGGDRASIL_DISABLE_PYTHON_C_API
     if (!(PyDict_Check(pyobj))) {
       ygglog_throw_error("ObjMetaschemaType::python2c: Python object must be a dict.");
     }
@@ -522,7 +526,8 @@ public:
       }
     }
     // Construct class
-    YggGeneric *cobj = new YggGeneric(this, arg);
+    cobj = new YggGeneric(this, arg);
+#endif // YGGDRASIL_DISABLE_PYTHON_C_API
     return cobj;
   }
   /*!
@@ -532,6 +537,10 @@ public:
    */
   PyObject* c2python(YggGeneric *cobj) const override {
     initialize_python("ObjMetaschemaType::c2python: ");
+    PyObject *pyobj = NULL;
+#ifdef YGGDRASIL_DISABLE_PYTHON_C_API
+    ygglog_throw_error("ObjMetaschemaType::c2python: Python disabled");
+#else // YGGDRASIL_DISABLE_PYTHON_C_API
     PyObject *py_args = PyTuple_New(0);
     PyObject *py_kwargs = PyDict_New();
     obj_t arg;
@@ -780,10 +789,11 @@ public:
     // Create class
     PyObject *py_class = import_python_class("yggdrasil.metaschema.datatypes.ObjMetaschemaType",
 					     "ObjDict");
-    PyObject *pyobj = PyObject_Call(py_class, py_args, py_kwargs);
+    pyobj = PyObject_Call(py_class, py_args, py_kwargs);
     if (pyobj == NULL) {
       ygglog_throw_error("ObjMetaschemaType::c2python: Failed to create ObjDict.");
     }
+#endif // YGGDRASIL_DISABLE_PYTHON_C_API
     return pyobj;
   }
 
@@ -817,7 +827,7 @@ public:
     char header_format[500] = "# Author ygg_auto\n"
       "# Generated by yggdrasil\n";
     if (strlen(p.material) != 0) {
-      sprintf(header_format + strlen(header_format), "usemtl %s\n", p.material);
+      snprintf(header_format + strlen(header_format), 500 - strlen(header_format), "usemtl %s\n", p.material);
     }
     ilen = (int)strlen(header_format);
     if (ilen >= (buf_size - msg_len)) {
@@ -981,9 +991,9 @@ public:
     } else {
       for (i = 0; i < p.npoint; i++) {
 	char ival[100];
-	sprintf(iline, "p");
+	snprintf(iline, 500, "p");
 	for (j = 0; j < p.nvert_in_point[i]; j++) {
-	  sprintf(ival, " %d", p.points[i][j] + 1);
+	  snprintf(ival, 100, " %d", p.points[i][j] + 1);
 	  strcat(iline, ival);
 	}
 	while (true) {
@@ -1010,13 +1020,13 @@ public:
     } else {
       for (i = 0; i < p.nline; i++) {
 	char ival[10];
-	sprintf(iline, "l");
+	snprintf(iline, 500, "l");
 	for (j = 0; j < p.nvert_in_line[i]; j++) {
-	  sprintf(ival, " %d", p.lines[i][j] + 1);
+	  snprintf(ival, 10, " %d", p.lines[i][j] + 1);
 	  strcat(iline, ival);
 	  if (p.line_texcoords != NULL) {
 	    if (p.line_texcoords[i][j] >= 0) {
-	      sprintf(ival, "/%d", p.line_texcoords[i][j] + 1);
+	      snprintf(ival, 10, "/%d", p.line_texcoords[i][j] + 1);
 	      strcat(iline, ival);
 	    }
 	  }
@@ -1045,21 +1055,21 @@ public:
     } else {
       for (i = 0; i < p.nface; i++) {
 	char ival[10];
-	sprintf(iline, "f");
+	snprintf(iline, 500, "f");
 	for (j = 0; j < p.nvert_in_face[i]; j++) {
-	  sprintf(ival, " %d", p.faces[i][j] + 1);
+	  snprintf(ival, 10, " %d", p.faces[i][j] + 1);
 	  strcat(iline, ival);
 	  strcat(iline, "/");
 	  if (p.face_texcoords != NULL) {
 	    if (p.face_texcoords[i][j] >= 0) {
-	      sprintf(ival, "%d", p.face_texcoords[i][j] + 1);
+	      snprintf(ival, 10, "%d", p.face_texcoords[i][j] + 1);
 	      strcat(iline, ival);
 	    }
 	  }
 	  strcat(iline, "/");
 	  if (p.face_normals != NULL) {
 	    if (p.face_normals[i][j] >= 0) {
-	      sprintf(ival, "%d", p.face_normals[i][j] + 1);
+	      snprintf(ival, 10, "%d", p.face_normals[i][j] + 1);
 	      strcat(iline, ival);
 	    }
 	  }
@@ -1088,13 +1098,13 @@ public:
     } else {
       for (i = 0; i < p.ncurve; i++) {
 	char ival[10];
-	sprintf(iline, "curv");
+	snprintf(iline, 500, "curv");
 	for (j = 0; j < 2; j++) {
-	  sprintf(ival, " %f", p.curve_params[i][j]);
+	  snprintf(ival, 10, " %f", p.curve_params[i][j]);
 	  strcat(iline, ival);
 	}
 	for (j = 0; j < p.nvert_in_curve[i]; j++) {
-	  sprintf(ival, " %d", p.curves[i][j] + 1);
+	  snprintf(ival, 10, " %d", p.curves[i][j] + 1);
 	  strcat(iline, ival);
 	}
 	while (true) {
@@ -1121,9 +1131,9 @@ public:
     } else {
       for (i = 0; i < p.ncurve2; i++) {
 	char ival[10];
-	sprintf(iline, "curv2");
+	snprintf(iline, 500, "curv2");
 	for (j = 0; j < p.nparam_in_curve2[i]; j++) {
-	  sprintf(ival, " %d", p.curves2[i][j] + 1);
+	  snprintf(ival, 10, " %d", p.curves2[i][j] + 1);
 	  strcat(iline, ival);
 	}
 	while (true) {
@@ -1150,29 +1160,29 @@ public:
     } else {
       for (i = 0; i < p.nsurf; i++) {
 	char ival[10];
-	sprintf(iline, "surf");
+	snprintf(iline, 500, "surf");
 	for (j = 0; j < 2; j++) {
-	  sprintf(ival, " %f", p.surface_params_u[i][j]);
+	  snprintf(ival, 10, " %f", p.surface_params_u[i][j]);
 	  strcat(iline, ival);
 	}
 	for (j = 0; j < 2; j++) {
-	  sprintf(ival, " %f", p.surface_params_v[i][j]);
+	  snprintf(ival, 10, " %f", p.surface_params_v[i][j]);
 	  strcat(iline, ival);
 	}
 	for (j = 0; j < p.nvert_in_surface[i]; j++) {
-	  sprintf(ival, " %d", p.surfaces[i][j] + 1);
+	  snprintf(ival, 10, " %d", p.surfaces[i][j] + 1);
 	  strcat(iline, ival);
 	  strcat(iline, "/");
 	  if (p.surface_texcoords != NULL) {
 	    if (p.surface_texcoords[i][j] >= 0) {
-	      sprintf(ival, "%d", p.surface_texcoords[i][j] + 1);
+	      snprintf(ival, 10, "%d", p.surface_texcoords[i][j] + 1);
 	      strcat(iline, ival);
 	    }
 	  }
 	  strcat(iline, "/");
 	  if (p.surface_normals != NULL) {
 	    if (p.surface_normals[i][j] >= 0) {
-	      sprintf(ival, "%d", p.surface_normals[i][j] + 1);
+	      snprintf(ival, 10, "%d", p.surface_normals[i][j] + 1);
 	      strcat(iline, ival);
 	    }
 	  }
@@ -1195,6 +1205,7 @@ public:
     ygglog_info("writing:\n%s",buf);
     buf[msg_len] = '\0';
     writer->String(buf, msg_len);
+    free(buf);
     return true;
   }
   /*!
