@@ -311,7 +311,7 @@ int serialize_obj(const seri_t s, char *buf, const size_t buf_size,
   char header_format[500] = "# Author ygg_auto\n"
     "# Generated by yggdrasil\n";
   if (strlen(p.material) != 0) {
-    sprintf(header_format + strlen(header_format), "usemtl %s\n", p.material);
+    snprintf(header_format + strlen(header_format), 500 - strlen(header_format), "usemtl %s\n", p.material);
   }
   ilen = (int)strlen(header_format);
   if (ilen >= (buf_size - msg_len)) {
@@ -376,18 +376,18 @@ int serialize_obj(const seri_t s, char *buf, const size_t buf_size,
   // Add face information
   for (i = 0; i < p.nface; i++) {
     char ival[10];
-    sprintf(iline, "f");
+    snprintf(iline, 500, "f");
     for (j = 0; j < 3; j++) {
-      sprintf(ival, " %d", p.faces[i][j] + 1);
+      snprintf(ival, 10, " %d", p.faces[i][j] + 1);
       strcat(iline, ival);
       strcat(iline, "/");
       if (p.face_texcoords[i][j] >= 0) {
-	sprintf(ival, "%d", p.face_texcoords[i][j] + 1);
+	snprintf(ival, 10, "%d", p.face_texcoords[i][j] + 1);
 	strcat(iline, ival);
       }
       strcat(iline, "/");
       if (p.face_normals[i][j] >= 0) {
-	sprintf(ival, "%d", p.face_normals[i][j] + 1);
+	snprintf(ival, 10, "%d", p.face_normals[i][j] + 1);
 	strcat(iline, ival);
       }
     }
