@@ -89,12 +89,19 @@ typedef long double _Complex complex_long_double;
 #define print_complex(x) printf("%lf+%lfj\n", (double)creal(x), (double)cimag(x))
 #endif
 
-
 #ifdef __cplusplus /* If this is a C++ compiler, use C linkage */
 extern "C" {
 #endif
 
 #include <math.h> // Required to prevent error when using mingw on windows
+#ifdef YGGDRASIL_DISABLE_PYTHON_C_API
+#ifndef PyObject
+#define PyObject void
+#endif
+#ifndef npy_intp
+#define npy_intp int
+#endif
+#else // YGGDRASIL_DISABLE_PYTHON_C_API
 #ifdef _DEBUG
 #undef _DEBUG
 #include <Python.h>
@@ -108,6 +115,7 @@ extern "C" {
 #include <numpy/ndarrayobject.h>
 #include <numpy/npy_common.h>
 #endif
+#endif // YGGDRASIL_DISABLE_PYTHON_C_API
   
 /*! @brief Wrapper for a complex number with float components. */
 typedef struct complex_float_t {
@@ -275,6 +283,9 @@ python_t init_python() {
 static inline
 int init_numpy_API() {
   int out = 0;
+#ifdef YGGDRASIL_DISABLE_PYTHON_C_API
+  out = -1;
+#else // YGGDRASIL_DISABLE_PYTHON_C_API
 #ifdef _OPENMP
 #pragma omp critical (numpy)
   {
@@ -288,6 +299,7 @@ int init_numpy_API() {
 #ifdef _OPENMP
   }
 #endif
+#endif // YGGDRASIL_DISABLE_PYTHON_C_API
   return out;
 };
 
@@ -299,6 +311,9 @@ int init_numpy_API() {
 static inline
 int init_python_API() {
   int out = 0;
+#ifdef YGGDRASIL_DISABLE_PYTHON_C_API
+  out = -1;
+#else // YGGDRASIL_DISABLE_PYTHON_C_API
 #ifdef _OPENMP
 #pragma omp critical (python)
   {
@@ -327,6 +342,7 @@ int init_python_API() {
 #ifdef _OPENMP
   }
 #endif
+#endif // YGGDRASIL_DISABLE_PYTHON_C_API
   return out;
 };
 
