@@ -6,10 +6,14 @@ python2R <- function(pyobj) {
   ver <- reticulate::py_get_attr(sys, 'version_info')
   pyv <- reticulate::py_to_r(reticulate::py_get_attr(ver, 'major'))
   np <- reticulate::import('numpy', convert=FALSE)
-  try(units::install_conversion_constant('ac', 'm**2', 4046.86), TRUE)
-  try(units::install_conversion_constant('a', 'm**2', 100.0), TRUE)
-  try(units::install_conversion_constant('j', 'J', 1.0), TRUE)
-  try(units::install_conversion_constant('ha', 'm**2', 10000.0), TRUE)
+  try(units::install_unit('ac', '4046.86 m**2'), TRUE)
+  try(units::install_unit('a', '100.0 m**2'), TRUE)
+  try(units::install_unit('j', 'J'), TRUE)
+  try(units::install_unit('ha', '10000.0 m**2'), TRUE)
+  # try(units::install_conversion_constant('ac', 'm**2', 4046.86), TRUE)
+  # try(units::install_conversion_constant('a', 'm**2', 100.0), TRUE)
+  # try(units::install_conversion_constant('j', 'J', 1.0), TRUE)
+  # try(units::install_conversion_constant('ha', 'm**2', 10000.0), TRUE)
   if (is(pyobj, "python.builtin.tuple")
       || is(pyobj, "python.builtin.list")) {
     pyobj_len <- reticulate::py_len(pyobj)
