@@ -88,8 +88,8 @@ class InstanceMetaschemaType(MetaschemaType):
         """
         # TODO: Normalization can be removed if metadata is normalized
         typedef = cls.normalize_definition(typedef)
-        assert(isinstance(obj, list))
-        assert(len(obj) == 2)
+        assert isinstance(obj, list)
+        assert len(obj) == 2
         args = JSONArrayMetaschemaType.decode_data(
             obj[0], {'items': typedef.get('args', [])})
         kwargs = JSONObjectMetaschemaType.decode_data(
@@ -107,9 +107,17 @@ class InstanceMetaschemaType(MetaschemaType):
             object: Python object of the specified type.
 
         """
-        typedef = cls.normalize_definition(typedef)
         args = JSONArrayMetaschemaType.generate_data(
             {'type': 'array', 'items': typedef.get('args', [])})
         kwargs = JSONObjectMetaschemaType.generate_data(
             {'type': 'object', 'properties': typedef.get('kwargs', {})})
         return typedef['class'](*args, **kwargs)
+
+    @classmethod
+    def get_test_data(cls, typedef=None):
+        r"""object: Test data."""
+        if typedef is None:
+            from yggdrasil.metaschema.datatypes.ClassMetaschemaType import (
+                ExampleClass)
+            typedef = {'type': 'instance', 'class': ExampleClass}
+        return super(InstanceMetaschemaType, cls).get_test_data(typedef)
