@@ -8,7 +8,7 @@ import threading
 import queue
 import multiprocessing
 import asyncio
-from yggdrasil.tools import YggClass
+from yggdrasil.tools import YggClass, sleep
 MPI = None
 _on_mpi = False
 _mpi_rank = -1
@@ -33,6 +33,14 @@ _lock_registry = weakref.WeakValueDictionary()
 logger = logging.getLogger(__name__)
 
 
+def test_target_error():  # pragma: debug
+    raise RuntimeError("Test error.")
+
+
+def test_target_sleep():  # pragma: debug
+    sleep(10.0)
+
+
 def check_processes():  # pragma: debug
     r"""Check for processes that are still running."""
     import psutil
@@ -186,10 +194,10 @@ class AliasMeta(type):
     def __new__(meta, name, bases, class_dict):
         cls = type.__new__(meta, name, bases, class_dict)
         for k in cls._base_meth:
-            assert(not hasattr(cls, k))
+            assert not hasattr(cls, k)
             add_aliased_method(cls, k, with_lock=cls._base_locked)
         for k in cls._base_attr:
-            assert(not hasattr(cls, k))
+            assert not hasattr(cls, k)
             add_aliased_attribute(cls, k, with_lock=cls._base_locked)
         cls._base_meth = []
         cls._base_attr = []
@@ -210,7 +218,7 @@ class AliasObject(object):
 
     """
 
-    __slots__ = ['_base']
+    __slots__ = ['_base', '__weakref__']
     _base_class_name = None
     _base_class = None
     _base_attr = []
@@ -242,7 +250,8 @@ class AliasObject(object):
             out.update(
                 dict((slot, getattr(self, slot))
                      for slot in base.__slots__
-                     if (hasattr(self, slot) and (slot != '_base_class')
+                     if (hasattr(self, slot)
+                         and (slot not in ['_base_class', '__weakref__'])
                          and (slot not in out))))
             for x in base.__bases__:
                 if x != object:
@@ -270,7 +279,9 @@ class AliasObject(object):
         r"""Disconnect from the aliased object by replacing it with
         a dummy object."""
         if self._base is not None:
-            self._base = self.dummy_copy
+            dummy = self.dummy_copy
+            del self._base
+            self._base = dummy
 
     def __del__(self):
         self.disconnect()
@@ -396,6 +407,10 @@ class ContextObject(MultiObject):
         task_method = task_context.task_method
         self._context = weakref.ref(task_context)
         self._base_class = self.get_base_class(task_context)
+        if ((self._base_class
+             and isinstance(self._base_class, type)
+             and issubclass(self._base_class, (LockedObject, ContextObject)))):
+            kwargs['task_context'] = task_context
         super(ContextObject, self).__init__(
             *args, task_method=task_method, **kwargs)
 
@@ -614,6 +629,14 @@ class Event(ContextObject):
         getattr(self, f'_{trigger}_callbacks').append(
             (callback, args, kwargs))
 
+    def disconnect(self):
+        r"""Disconnect from the aliased object by replacing it with
+        a dummy object."""
+        if Event is not None:
+            super(Event, self).disconnect()
+            self._set = self._base.set
+            self._clear = self._base.clear
+
 
 class ValueEvent(Event):
     r"""Class for handling storing a value that also triggers an event."""
@@ -760,6 +783,13 @@ class Task(ContextObject):
         elif hasattr(self._base, 'terminate'):
             return self._base.terminate(*args, **kwargs)
 
+    def disconnect(self):
+        r"""Disconnect from the aliased object by replacing it with
+        a dummy object."""
+        self._target = None
+        if Task is not None:
+            super(Task, self).disconnect()
+
 
 class TaskLoop(Task):
     r"""Class for looping over a task."""
@@ -807,6 +837,14 @@ class TaskLoop(Task):
         r"""Finalize a run."""
         self.break_loop()
 
+    def disconnect(self):
+        r"""Disconnect from the aliased object by replacing it with
+        a dummy object."""
+        self.break_flag.disconnect()
+        self._loop_target = None
+        if TaskLoop is not None:
+            super(TaskLoop, self).disconnect()
+
 
 class DummyQueue(DummyContextObject):  # pragma: no cover
 
@@ -941,13 +979,16 @@ class Dict(ContextObject):
         r"""Disconnect from the aliased object by replacing it with
         a dummy object."""
         try:
-            final_value = self._base.copy()
+            final_value = {k: v for k, v in self._base.items()}
         except BaseException:  # pragma: debug
             final_value = {}
-        if isinstance(self._base, LockedDict):
+        if LockedDict and isinstance(self._base, LockedDict):
             self._base.disconnect()
         if getattr(self._base, '_manager', None) is not None:
             self._base._manager.shutdown()
+            self._base._manager.join()
+            del self._base._manager
+            self._base._manager = None
         if hasattr(self._base, '_close'):
             self._base._close()
         if Dict is not None:
@@ -1027,7 +1068,7 @@ class WaitableFunction(object):
 
     __slots__ = ["function", "polling_interval"]
 
-    def __init__(self, function, polling_interval=0.1):
+    def __init__(self, function, polling_interval=0.01):
         self.function = function
         self.polling_interval = polling_interval
 
@@ -1280,7 +1321,7 @@ class MPIErrorExchange(object):
             self.send((local_tag, msg))
             out = self.recv(wait=True)
             complete, results = out[0]  # self.recv(wait=True)[0]
-            assert(complete)
+            assert complete
         else:
             if (self.outgoing is None) and (msg in self.closing_messages):
                 self.outgoing = msg
@@ -1297,7 +1338,7 @@ class MPIErrorExchange(object):
         if remote_error and (not local_error) and (not dont_raise):  # pragma: debug
             raise MPIPartnerError("Error on another process.")
         if check_equal and not (remote_error or local_error):
-            assert(all((x == local_tag) for x in all_tag))
+            assert all((x == local_tag) for x in all_tag)
         if check_complete:
             return all(x[1][1] in self.closing_messages
                        for x in results)
@@ -1327,7 +1368,8 @@ class YggTask(YggClass):
 
     _disconnect_attr = (YggClass._disconnect_attr
                         + ['context', 'lock', 'process_instance',
-                           'error_flag', 'start_flag', 'terminate_flag'])
+                           'error_flag', 'start_flag', 'terminate_flag',
+                           'pipe'])
     
     def __init__(self, name=None, target=None, args=(), kwargs=None,
                  daemon=False, group=None, task_method='thread',
@@ -1546,7 +1588,7 @@ class YggTask(YggClass):
             # if self.is_alive():
             #     self.join(self.timeout)
             self.wait(timeout=self.timeout)
-            assert(not self.is_alive())
+            assert not self.is_alive()
         # if self.as_process:
         #     self.process_instance.terminate()
 
@@ -1625,7 +1667,7 @@ class YggTaskLoop(YggTask):
     r"""Class to run a loop inside a thread/process."""
 
     _disconnect_attr = (YggTask._disconnect_attr
-                        + ['break_flag', 'loop_flag'])
+                        + ['break_flag', 'loop_flag', 'unpause_flag'])
 
     def __init__(self, *args, **kwargs):
         super(YggTaskLoop, self).__init__(*args, **kwargs)
@@ -1767,3 +1809,38 @@ class YggTaskLoop(YggTask):
         self.debug("terminate")
         self.set_break_flag()
         super(YggTaskLoop, self).terminate(*args, **kwargs)
+
+
+class MemoryTracker(YggTaskLoop):
+    r"""Class to track the memory used by another process.
+
+    Args:
+        pid (int): Process ID for the process that should be tracked.
+        interval (float, optional): Time (in seconds) that should be
+            waiting between memory usage checks. Defaults to 1 second.
+
+    """
+
+    def __init__(self, pid, interval=1.0):
+        self.track_pid = pid
+        self.track_interval = interval
+        self.record = []
+        super(MemoryTracker, self).__init__(target=self.record_memory)
+
+    def record_memory(self):
+        import psutil
+        if not psutil.pid_exists(self.track_pid):  # pragma: debug
+            self.set_break_flag()
+            return
+        process = psutil.Process(self.track_pid)
+        children = process.children(recursive=True)
+        total_mem = process.memory_info().rss / 1024 ** 2
+        child_mem = 0
+        for x in children:
+            child_mem += x.memory_info().rss / 1024 ** 2
+        self.record.append(total_mem + child_mem)
+        sleep(self.track_interval)
+
+    @property
+    def max_memory(self):
+        return max(self.record)
