@@ -267,6 +267,12 @@ class YggRunner(YggClass):
         validate (bool, optional): If True, the validation scripts for each
             modle (if present), will be run after the integration finishes
             running. Defaults to False.
+        with_debugger (str, optional): Tool (and any flags for the tool)
+            that should be used to run models.
+        disable_python_c_api (bool, optional): If True, the Python C API will
+            be disabled. Defaults to False.
+        with_asan (bool, optional): Compile and run all models with the
+            address sanitizer. Defaults to False.
 
     Attributes:
         namespace (str): Name that should be used to uniquely identify any
@@ -286,7 +292,12 @@ class YggRunner(YggClass):
                  ygg_debug_prefix=None, connection_task_method='thread',
                  as_service=False, complete_partial=False,
                  partial_commtype=None, production_run=False,
-                 mpi_tag_start=None, yaml_param=None, validate=False):
+                 mpi_tag_start=None, yaml_param=None, validate=False,
+                 with_debugger=None, disable_python_c_api=False,
+                 with_asan=False):
+        kwargs_models = {'with_debugger': with_debugger,
+                         'disable_python_c_api': disable_python_c_api,
+                         'with_asan': with_asan}
         self.mpi_comm = None
         name = 'runner'
         if MPI is not None:
@@ -331,6 +342,11 @@ class YggRunner(YggClass):
                 partial_commtype=partial_commtype, yaml_param=yaml_param)
             self.connectiondrivers = self.drivers['connection']
             self.modeldrivers = self.drivers['model']
+            for k, v in kwargs_models.items():
+                if not v:
+                    continue
+                for x in self.modeldrivers.values():
+                    x[k] = v
             for x in self.modeldrivers.values():
                 if x['driver'] == 'DummyModelDriver':
                     x['runner'] = self
