@@ -116,8 +116,8 @@ class SerializeBase(tools.YggClass):
         # If the serialization cannot be concatenated, then it is not framed by
         # definition and would be meaningless if read-in incrementally
         if not cls.concats_as_str:
-            assert(not cls.is_framed)
-            assert(cls.default_read_meth == 'read')
+            assert not cls.is_framed
+            assert cls.default_read_meth == 'read'
         
     @classmethod
     def object2dict(cls, obj, **kwargs):
@@ -165,6 +165,40 @@ class SerializeBase(tools.YggClass):
         """
         return objects
 
+    def get_status_message(self, nindent=0, extra_lines_before=None,
+                           extra_lines_after=None):
+        r"""Return lines composing a status message.
+        
+        Args:
+            nindent (int, optional): Number of tabs that should be used to
+                indent each line. Defaults to 0.
+            extra_lines_before (list, optional): Additional lines that should
+                be added to the beginning of the default print message.
+                Defaults to empty list if not provided.
+            extra_lines_after (list, optional): Additional lines that should
+                be added to the end of the default print message. Defaults to
+                empty list if not provided.
+                
+        Returns:
+            tuple(list, prefix): Lines composing the status message and the
+                prefix string used for the last message.
+
+        """
+        if extra_lines_before is None:
+            extra_lines_before = []
+        if extra_lines_after is None:
+            extra_lines_after = []
+        prefix = nindent * '\t'
+        lines = ['%s%s' % (prefix, x) for x in extra_lines_before]
+        lines += ['%s%-15s:' % (prefix, 'sinfo')]
+        lines += [prefix + '\t' + x for x in
+                  self.pprint(self.serializer_info).splitlines()]
+        lines += ['%s%-15s:' % (prefix, 'typedef')]
+        lines += [prefix + '\t' + x for x in
+                  self.pprint(self.typedef).splitlines()]
+        lines += ['%s%s' % (prefix, x) for x in extra_lines_after]
+        return lines, prefix
+
     @classmethod
     def get_testing_options(cls, table_example=False, array_columns=False,
                             include_oldkws=False, table_string_type='bytes'):
@@ -207,7 +241,7 @@ class SerializeBase(tools.YggClass):
         if array_columns:
             table_example = True
         if table_example:
-            assert(table_string_type in ['bytes', 'unicode', 'string'])
+            assert table_string_type in ['bytes', 'unicode', 'string']
             if table_string_type == 'string':
                 table_string_type = 'unicode'
             int_type = np.int32
@@ -250,6 +284,10 @@ class SerializeBase(tools.YggClass):
                                       'field_names': ['name', 'count', 'size'],
                                       'field_units': ['n/a', umol, 'cm']})
                 out['extra_kwargs']['format_str'] = out['kwargs']['format_str']
+                out['objects'] = [
+                    [units.add_units(x, u) for x, u in
+                     zip(row, out['kwargs']['field_units'])]
+                    for row in out['objects']]
                 if 'format_str' in cls._attr_conv:
                     out['extra_kwargs']['format_str'] = tools.str2bytes(
                         out['extra_kwargs']['format_str'])
@@ -323,9 +361,9 @@ class SerializeBase(tools.YggClass):
                 out[k] = copy.deepcopy(v)
         for k in out.keys():
             v = out[k]
-            if isinstance(v, (bytes, list, tuple)):
+            try:
                 out[k] = tools.bytes2str(v, recurse=True)
-            else:
+            except TypeError:
                 out[k] = v
         return out
 
@@ -572,7 +610,7 @@ class SerializeBase(tools.YggClass):
                 fmts = serialize.extract_formats(v)
                 if 'type' in typedef:
                     if (typedef.get('type', None) == 'array'):
-                        assert(len(typedef.get('items', [])) == len(fmts))
+                        assert len(typedef.get('items', [])) == len(fmts)
                     # This continue is covered, but the optimization
                     # causes it to be skipped at runtime
                     # https://bitbucket.org/ned/coveragepy/issues/198/
@@ -609,7 +647,7 @@ class SerializeBase(tools.YggClass):
                 if isinstance(typedef['items'], dict):
                     typedef['items'] = [copy.deepcopy(typedef['items'])
                                         for _ in range(len(v))]
-                assert(len(v) == len(typedef.get('items', [])))
+                assert len(v) == len(typedef.get('items', []))
                 # if len(v) != len(typedef.get('items', [])):
                 #     warnings.warn('%d %ss provided, but only %d items in typedef.'
                 #                   % (len(v), k, len(typedef.get('items', []))))
@@ -635,7 +673,7 @@ class SerializeBase(tools.YggClass):
                     setattr(self, rk, v)
         return typedef
 
-    def func_serialize(self, args):
+    def func_serialize(self, args):  # pragma: debug
         r"""Serialize a message.
 
         Args:
@@ -648,7 +686,7 @@ class SerializeBase(tools.YggClass):
         """
         raise NotImplementedError("func_serialize not implemented.")
 
-    def func_deserialize(self, msg):
+    def func_deserialize(self, msg):  # pragma: debug
         r"""Deserialize a message.
 
         Args:
